pub struct RootIssuerDelegation {
pub issuer_did: Did,
pub issuer_public_key: PublicKey,
pub granted_permissions: Vec<Permission>,
pub effective_at: Timestamp,
pub expires_at: Option<Timestamp>,
pub purpose: String,
}Expand description
Operational AVC issuer authority delegated by the root.
Fields
issuer_did: DidOperational issuer DID.
issuer_public_key: PublicKeyOperational issuer public key.
granted_permissions: Vec<Permission>Permissions granted by the root authority.
effective_at: TimestampHLC activation timestamp.
expires_at: Option<Timestamp>Optional HLC expiry timestamp.
purpose: StringHuman-readable bounded purpose.
Implementations
Sourceimpl RootIssuerDelegation
impl RootIssuerDelegation
Sourcepub fn root_artifact_payload(
&self,
config: &GenesisCeremonyConfig,
public_key_package: &RootPublicKeyPackage,
transcript_hash: Hash256,
) -> Result<Vec<u8>>
pub fn root_artifact_payload( &self, config: &GenesisCeremonyConfig, public_key_package: &RootPublicKeyPackage, transcript_hash: Hash256, ) -> Result<Vec<u8>>
Canonical payload signed by the root threshold authority for the predeclared deterministic signing set.
Sourcepub fn root_artifact_payload_for_signers(
&self,
config: &GenesisCeremonyConfig,
public_key_package: &RootPublicKeyPackage,
transcript_hash: Hash256,
signer_ids: &[u16],
) -> Result<Vec<u8>>
pub fn root_artifact_payload_for_signers( &self, config: &GenesisCeremonyConfig, public_key_package: &RootPublicKeyPackage, transcript_hash: Hash256, signer_ids: &[u16], ) -> Result<Vec<u8>>
Canonical payload signed by the root threshold authority for the exact signer metadata carried by a root signature.